pg_idna

Function idna_is_punycode

pub const fn idna_is_punycode(slice: &[u8]) -> bool
Checks if input is Punycode.

This is merely a hint, as it only checks for the xn-- prefix. Thus, invalid punycode, or even non-ASCII, could return true.

Copyright (c) 2013-2022 The rust-url developers

This code was copied from rust-url and is used under the terms of the MIT license.