pg_idna

Function idna_to_unicode_lossy

pub fn idna_to_unicode_lossy(input: &str, adl: &str, h: &str) -> String
Attemps to encode input as UTF-8.

If input is not valid Punycode, errors are denoted by U+FFFD REPLACEMENT CHARACTERs in the output.

Panics

This function will panic under any of the following conditions:

Defaults

For more information, see Uts46::to_unicode.